<?php
//
// +---------------------------------------------------------------------------+
// | Daily Quote Plugin v1.0.5                                                 |
// |                                                                           |
// | functions.inc                                                             |
// | This file does two things: 1) it implements the necessary Geeklog Plugin  |
// | API method and 2) implements all the common code needed by the Daily      |
// | Quote PHP files.                                                          |
// |                                                                           |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2002 by the following authors:                              |
// |                                                                           |
// | Author: Alf Deeley aka machinari - ajdeeley@summitpages.ca                |
// | Constructed with the Universal Plugin                                     |
// | Copyright (C) 2002 by the following authors:                              |
// | Tom Willett                 -    twillett@users.sourceforge.net           |
// | Blaine Lang                 -    langmail@sympatico.ca                    |
// | The Universal Plugin is based on prior work by:                           |
// | Tony Bibbs                  -    tony@tonybibbs.com                       |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

/**
* Language file Include
*/
$langfile = $_CONF['path'] . 'plugins/dailyquote/language/' . $_CONF['language'] . '.php';

if (file_exists ($langfile)) 
{
    include_once ($langfile);
}
else 
{
    include_once ($_CONF['path'] . 'plugins/dailyquote/language/english.php');
}

/*
* Include dailyquote config file
*/
require_once ($_CONF['path'] . 'plugins/dailyquote/config.php');

// +---------------------------------------------------------------------------+
// | Geeklog Plugin API Implementations                                        |
// +---------------------------------------------------------------------------+

/**
* Returns the items for this plugin that should appear on the main menu
*
* NOTE: this MUST return the url/value pairs in the following format
* $<arrayname>[<label>] = <url>
*
* @return    array   Associative array of menu items to be added to menu
*
*/
function plugin_getmenuitems_dailyquote()
{
    global $_CONF, $_USER, $LANG_DQ, $DQ_TABLES;

    // Retrieve access Settings
    $query = DB_query("SELECT anonview FROM {$DQ_TABLES['dailyquote_settings']}");
    list($anonview) = DB_fetchArray($query);

    $menulabel = "{$LANG_DQ['menulabel']}";                // Put your menu label here
    $menurul = $_CONF['site_url'] . "/dailyquote/index.php";     // Menu url here
    
    $menuitems = array();

    // Check user has rights to view this cb, if so, do it.
    if ((($anonview == '1') && ($_USER['uid'] < 2)) || ($_USER['uid'] > 1)) {
        $menuitems["$menulabel"] = $menurul;
    }
    return $menuitems;
}

/**
*
* Geeklog is checking to see if this plugin supports comments, tell it no!
* NOTE: to support comments you must use the same date/time based ID for your
* widget.  In other words, to make primary keys for your plugin you should call
* makesid().  Comments are keyed off of that...it is a limitation on how geeklog
* does comments.
*
* @return   boolean true or false
*
*/
function plugin_commentsupport_dailyquote()
{
    return false;
}

/**
* Shows the statistics for the plugin on stats.php.  If
* $showsitestats is 1 then we are to only print the overall stats in the 'site
* statistics' box otherwise we show the detailed stats for the plugin
*
* @param    int showsitestate   Flag to let us know which stats to get
* @return   string  returns formatted HTML to insert in stats page
*
*/
function plugin_showstats_dailyquote($showsitestats)
{
    global $_CONF, $_USER, $DQ_TABLES, $LANG_DQ;

    // Retrieve access Settings
    $query = DB_query("SELECT anonview FROM {$DQ_TABLES['dailyquote_settings']}");
    list($anonview) = DB_fetchArray($query);

    // Check user has rights to view this cb, if so, do it.
    if ((($anonview == '1') && ($_USER['uid'] < 2)) || ($_USER['uid'] > 1)) {

        $stat_templates = new Template($_CONF['path_layout'] . 'stats');
        $stat_templates->set_file(array('itemstats'=>'itemstatistics.thtml',
                                'statrow'=>'singlestat.thtml'));
        if ($showsitestats == 1) {
            $total_pages=DB_count($DQ_TABLES['dailyquote_quotes'], 'Status', '1');
            $retval = "<table border = '0' width='100%' cellspacing='0' cellpadding='0'>";
            $retval .= "<tr><td>" . $LANG_DQ['noquotes'] . "</td>";
            $retval .= "<td align='right'>" . $total_pages . "&nbsp;&nbsp </td></tr></table>";
        } else {
            $result = DB_query("SELECT quoted, COUNT(*) FROM {$DQ_TABLES['dailyquote_quotes']} q, {$DQ_TABLES['dailyquote_lookup']} l WHERE ID=QID AND l.Status='1' GROUP BY Quoted ORDER BY 2 desc, 1 asc LIMIT 10");
            $nrows  = DB_numRows($result);
            $retval .= COM_startBlock($LANG_DQ['StatsMsg1']);
            if ($nrows > 0) {
                $stat_templates->set_var('item_label', $LANG_DQ['StatsMsg3']);
                $stat_templates->set_var('stat_name', $LANG_DQ['StatsMsg4']);
                for ($i = 0; $i < $nrows; $i++) {
                    $A = DB_fetchArray($result);
                    //$quoted = urlencode($A['quoted']);//dunno if this is necessary just yet.
                    $stat_templates->set_var('item_url', $_CONF['site_url'] . '/dailyquote/search.php?stat=' . $A['quoted']);
                    $stat_templates->set_var('item_text', $A['quoted']);
                    $stat_templates->set_var('item_stat', $A['COUNT(*)']);
                    $stat_templates->parse('stat_row','statrow',true); 
                }
                $stat_templates->parse('output','itemstats');
                $retval .= $stat_templates->finish($stat_templates->get_var('output'));
            } else {
                $retval .= $LANG_DQ['StatsMsg2'];
            }   
            $retval .= COM_endBlock();
        }
        return $retval;
    }
}

/**
* This will put an option for the plugin in the command and control block on moderation.php
*
* @return   array   Array containing (plugin name, admin url, url of plugin icon)
*
*/
function plugin_cclabel_dailyquote()
{
    global $_CONF, $LANG_DQ;

    return array($LANG_DQ['plugin_name'],$_CONF['site_admin_url'] . '/plugins/dailyquote/index.php',$_CONF['site_url'] . '/dailyquote/images/dailyquote.gif');
}

/**
* Returns the administrative option for this plugin
*
* @return   array   Array containing (plugin name, plugin admin url, # of items in plugin or '')
*
*/
function plugin_getadminoption_dailyquote()
{
    global $_CONF, $DQ_TABLES, $LANG_DQ;

    if (SEC_inGroup('Root')) {
        $result = DB_query("SELECT COUNT(*) FROM {$DQ_TABLES['dailyquote_quotes']} WHERE Status=0");
        list($submittedquotes) = DB_fetchArray($result);
        return array($LANG_DQ['admin_menu'], $_CONF['site_admin_url'] . '/plugins/dailyquote/index.php', $submittedquotes);
    }
}

/**
* Returns the user option for this plugin
*
* @return   array   Array containing (plugin name, plugin user url, 0)
*
*/
function plugin_getuseroption_dailyquote()
{
    global $_CONF, $_USER, $LANG_DQ, $DQ_TABLES;

    // Retrieve access settings
    $query = DB_query("SELECT anonadd, loginadd FROM {$DQ_TABLES['dailyquote_settings']}");
    list($anonadd,$loginadd) = DB_fetchArray($query);

    if (SEC_hasRights('dailyquote.edit')){
        return array($LANG_DQ['user_menu2'], $_CONF['site_url'] . '/dailyquote/manage.php', 0);
    }
    elseif ((($anonadd == '1') && ($_USER['uid'] < 2)) || (($loginadd == '1') && ($_USER['uid'] > 2)) || (SEC_hasRights('dailyquote.add'))) {
        return array($LANG_DQ['user_menu1'], $_CONF['site_url'] . '/dailyquote/add.php', 0);
    }
}

//adds variables to the user's profile
function plugin_profilevariablesdisplay_dailyquote($uid, &$template)
{
    global $_TABLES, $_CONF, $LANG_DQ, $DQ_TABLES, $_USER;

    // Retrieve access Settings
    $anonview = DB_getItem($DQ_TABLES['dailyquote_settings'],'anonview');

    // Check user has rights to view this, if so, do it.
    if (($anonview == '1') || ($_USER['uid'] >= '2')) {
        $postlimit="10";        // How many posts you want displayed

        $query = DB_query ("SELECT ID,Quotes,Date FROM {$DQ_TABLES['dailyquote_quotes']} WHERE UID='$uid' AND Status='1' ORDER BY Date DESC LIMIT {$postlimit}");
        //************************
        $template->set_var ('end_block', COM_endBlock());
        $template->parse ('story_row', 'strow', true);
        //*************************

        $template->set_var ('start_block_last10plugin', COM_startBlock( $LANG_DQ['proflastqtxt'] . DB_getItem ($_TABLES['users'], 'username', "uid = $uid")));
        $numq = 0;
        if (DB_numRows($query) > 0){
            while (list($qid,$quote,$date) = DB_fetchArray($query)) {
                if (strlen($quote) > 32){
                    $quote = substr($quote, 0, 32) . '...';
                }
                $numq++;
                $postdate = COM_getUserDateTimeFormat ($date);
                $template->set_var ('row_number', $numq . '.');
                $template->set_var ('plugin_begin_href', '<a href="' . $_CONF['site_url'] . '/dailyquote/search.php?qid=' . $qid . '&amp;show=quote">');
                $template->set_var ('plugin_title', $quote);
                $template->set_var ('plugin_end_href', '</a>');
                $template->set_var ('plugin_date', $postdate[0]);
                $template->parse ('pluginpostrow', 'plgprow', true);
            }
        } else {
            $template->set_var ('plugin_row', '<tr><td>' .$LANG_DQ['profnone']. '</td></tr>');
            //$template->parse ('pluginpostrow', 'plgprow', true);
        }
        
        $template->set_var ('end_block', COM_endBlock());
        $template->parse ('plugin_last10_table', 'plgtable', true);
    }
}


//addds total stats to the user's profile
function plugin_profilestatsvariablesdisplay_dailyquote ($uid, &$template)
{
    global $LANG_DQ, $DQ_TABLES, $_USER;

    // Retrieve access Settings
    $anonview = DB_getItem($DQ_TABLES['dailyquote_settings'],'anonview');

    // Check user has rights to view this, if so, do it.
    if (($anonview == '1') || ($_USER['uid'] > '1')) {
        $count = DB_count ($DQ_TABLES['dailyquote_quotes'], array('UID', 'Status'), array($uid, '1'));
        $template->set_var ('lang_number_plugin', $LANG_DQ['profnumqtxt']);
        $template->set_var ('number_plugin', $count);
        $template->parse ('plugin_stats_number_row', 'plgsrow', true);
    }
}

/**
* Geeklog is asking us to provide any new items that show up in the type drop-down
* on search.php.  Let's let users search the Filelistings in the Filemgmt Plugin
*
*/

function plugin_searchtypes_dailyquote() 
{
    global $LANG_DQ;

    $tmp['dailyquote'] = $LANG_DQ['glsearchlabel'];
    return $tmp;
}

/**
* this searches for pages matching the user query and returns an array of 
* for the header and table rows back to search.php where it will be formated and
* printed 
*
* @query            string          Keywords user is looking for
* @datestart        date/time       Start date to get results for
* @dateend          date/time       End date to get results for
* @topic            string          The topic they were searching in
* @type             string          Type of items they are searching
* @author           string          Get all results by this author
*
*/

function plugin_dopluginsearch_dailyquote($query, $datestart, $dateend, $topic, $type, $author) 
{
    global $_TABLES, $_CONF, $_USER, $LANG_DQ00, $LANG_DQ, $DQ_TABLES;

    // Retrieve access Settings
    $access = DB_query("SELECT anonview FROM {$DQ_TABLES['dailyquote_settings']}");
    list($anonview) = DB_fetchArray($access);

    // Check user has rights to view this results, if so, do it.
    if ((($anonview == '1') && ($_USER['uid'] < 2)) || ($_USER['uid'] > 1)) {

        if (empty($type)) {
            $type = 'all';
        }

        // Bail if we aren't supppose to do our search
        if ($type <> 'all' AND $type <> 'dailyquote') {
            $plugin_results = new Plugin();
            $plugin_results->plugin_name = $LANG_DQ['plugin_name'];
            $plugin_results->searchlabel = $LANG_DQ['glsearchlabel'] . $LANG_DQ['glsearchlabel_results'];
            return $plugin_results;
        }

        $query = addslashes($query);
        //if (empty($query)){
        //    return;
        //}

        // Build search SQL
        $sql = "SELECT DISTINCT ID, Quotes, Quoted, q.UID, username";
        $sql .= " FROM {$DQ_TABLES['dailyquote_quotes']} q, {$DQ_TABLES['dailyquote_lookup']} l, {$_TABLES['users']} gl";
        $sql .= " WHERE (q.Status='1' AND q.UID=gl.uid AND l.QID=ID AND l.Status='1')";
        $sql .= " AND (Quotes like '%$query%'";
        $sql .= " OR Quoted like '%$query%'";
        $sql .= " OR username like '%$query%'";
        $sql .= " OR Source like '%$query%')";

        /*if (!empty($datestart) && !empty($dateend)) {
            $delim = substr($datestart, 4, 1);
            $DS = explode($delim,$datestart);
            $DE = explode($delim,$dateend);
            $startdate = mktime(0,0,0,$DS[1],$DS[2],$DS[0]);
            $enddate = mktime(0,0,0,$DE[1],$DE[2],$DE[0]) + 3600;
            $sql .= " AND (UNIX_TIMESTAMP(q.Date) BETWEEN '$startdate' AND '$enddate')";
        }*/

        if (!empty($author)) {
            $sql .= " AND q.UID='$author'";
        }

        $sql .= " ORDER BY Date DESC";
        COM_errorLOG("dailyquote Search: ".$sql);

        // Perform search
        $result = DB_query($sql);

        // OK, now create new plugin object and insert table header labels
        require_once($_CONF['path_system'] . 'classes/plugin.class.php');
        $plugin_results = new Plugin();
        $plugin_results->plugin_name = $LANG_DQ['plugin_name'];
        $plugin_results->searchlabel = $LANG_DQ['glsearchlabel_results'];
        $plugin_results->addSearchHeading($LANG_DQ['quotation']);
        $plugin_results->addSearchHeading($LANG_DQ['quoted']);
        $plugin_results->addSearchHeading($LANG_DQ['contributor']);
        $mycount = DB_numRows($result);

        // NOTE if any of your data items need to be links then add them here! 
        // make sure data elements are in an array and in the same order as your
        // headings above!
        for ($i = 1; $i <= $mycount; $i++) {
            $A = DB_fetchArray($result);
            if (strlen($A['Quotes']) > 64){
                $quotes = substr($A['Quotes'], 0, 64) . '...';
            } else $quotes = $A['Quotes'];
            if (strlen($A['Quoted']) > 24){
                $quoted = substr($A['Quoted'], 0, 24) . '...';
            } else $quoted = $A['Quoted'];
            $searchcount++;
            $url = $_CONF[site_url]. "/dailyquote/search.php?qid=" . $A['ID'];
            $row = array("<li><a href=\"{$url}&show=quote\">{$quotes}</a>", "<a href=\"{$url}&show=quoted\">{$quoted}</a>", "<a href=\"{$url}&show=name\">{$A['username']}</a>");
            $plugin_results->addSearchResult($row);
        }
        
        $plugin_results->num_searchresults = $searchcount;
        $plugin_results->num_itemssearched = DB_count($DQ_TABLES['dailyquote_quotes']);

        return $plugin_results;
    }
}

/**
  * Whats New Block API Support
*/
function plugin_whatsnewsupported_dailyquote(){
    global $_CONF, $DQ_TABLES, $LANG_DQ, $DQ_CONF, $_USER;

    $result = DB_query("SELECT anonview, whatsnew FROM {$DQ_TABLES['dailyquote_settings']}");
    list($anonview,$whatsnew) = DB_fetchArray($result);

    if((!$result) || ($whatsnew == '0') || (($anonview == '0') && ($_USER['uid'] < 2))){
        return;
    } else {
        return array($LANG_DQ['whatsnewlabel'],sprintf($LANG_DQ['whatsnewperiod'], $DQ_CONF['whatsnewperioddays']));
    }
}

/**
  * API function provides the content of our "What's New" feed
*/
function plugin_getwhatsnew_dailyquote(){
    global $_TABLES, $DQ_TABLES, $_CONF, $LANG_DQ, $DQ_CONF;

    $sql = "SELECT DISTINCT ID, Quoted 
                FROM {$DQ_TABLES['dailyquote_quotes']} q, {$DQ_TABLES['dailyquote_lookup']} l
                WHERE Date >= DATE_SUB(NOW(), INTERVAL {$DQ_CONF['whatsnewperioddays']} DAY )
                AND q.Status='1' AND l.QID=ID AND l.Status='1'
                ORDER  BY Date DESC LIMIT 15 ";
    $result = DB_query( $sql );
    $nrows = DB_numRows( $result );
    if( $nrows == 0 ) {
        $items = $LANG_DQ['newempty'] . '<br />' . LB;
    } else {
        $items = array();
        for( $i = 0; $i < $nrows; $i++ ) {
            list($qid, $quoted) = DB_fetchArray( $result );
            $str = "<a href=\"{$_CONF['site_url']}/dailyquote/search.php?qid=$qid&show=quote\">";
            $str .= stripslashes(substr($quoted,0,$DQ_CONF['whatsnewnamelength']));
            $str .= '</a>';
            $items[] = $str;
        }
    }
    return $items;
}

/**
* Return the current version of code. 
* Used in the Plugin Editor to show the registered version and code version
*/
function plugin_chkVersion_dailyquote()
{
    global $DQ_CONF;

    return $DQ_CONF['version'];
}

/**
* Removes the datastructures for this plugin from the Geeklog database.
* This routine will get called from the Plugin install program if user select De-Install or if Delete is used in the Plugin Editor.
* The Plugin Installer will also call this routine upon and install error to remove anything it has created.
* The Plugin installer will pass the optional parameter which will then double check that plugin has first been disabled. 
* 
* For this plugin, this routine will also remove the Block definition.
* 
* Returns True if all Plugin related data is removed without error
*
* @param    string   $installCheck     Defult is blank but if set, check if plugin is disabled first
* @return   boolean True if successful false otherwise
*
*/  
function plugin_uninstall_dailyquote($installCheck='')
{
    global $_TABLES, $DQ_TABLES, $LANG_DQ00, $LANG_DQ;

    $pi_name='dailyquote';
    $FEATURES = array ( 'dailyquote.edit', 'dailyquote.view', 'dailyquote.add');
    $TABLES = array ('dailyquote_quotes','dailyquote_cat','dailyquote_lookup','dailyquote_settings');
    
    // Check and see if plugin is still enabled - if so display warning and exit
    if ($installCheck != '' && DB_getItem($_TABLES['plugins'],'pi_enabled', 'pi_name = "' .$pi_name. '"')) {
        COM_errorLog("Plugin is installed and enabled. Disable first if you want to de-install it",1);
        $display = COM_siteHeader();
        $display .= COM_startBlock($LANG_DQ00['warning']);
        $display .= $LANG_DQ00['enabled'];
        $display .= COM_endBlock();
        $display .= COM_siteFooter();
        echo $display;
        exit;
    }
        
    // Ok to proceed and delete plugin -- Unregister the plugin with Geeklog
    COM_errorLog('Attempting to unregister the Daily Quote plugin from Geeklog',1);
    DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'dailyquote'",1);

    // Drop dailyquote tables
    foreach($TABLES as $table) {
        $t = $DQ_TABLES["$table"];
        COM_errorLog("Removing Table $t",1);
        DB_query("DROP TABLE $t",1);
    }

    //remove dq blocks created by install
    COM_errorLog("Removing $pi_name blocks",1);
    DB_query("DELETE FROM {$_TABLES['blocks']} WHERE name='dqmenu' LIMIT 1",1);
    DB_query("DELETE FROM {$_TABLES['blocks']} WHERE name='dailyquote' LIMIT 1",1);

    // Remove Security for this plugin
    $grp_id = DB_getItem($_TABLES['vars'], 'value', "name = '{$pi_name}_gid'");
    
    COM_errorLog("Removing $pi_name Admin Group", 1);
    DB_query("DELETE FROM {$_TABLES['groups']} WHERE grp_id = $grp_id",1);
    DB_query("DELETE FROM {$_TABLES['vars']} WHERE name = '{$pi_name}_gid'");
    COM_errorLog("Removing root users from admin of $pi_name");
    DB_query("DELETE FROM {$_TABLES['group_assignments']} WHERE ug_main_grp_id = $grp_id",1);
    
    // Remove all the associated features -- access rights
    foreach ($FEATURES as $feature) {
        COM_errorLog("Removing $feature feature and rights to it",1);
        $feat_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = '$feature'");
        DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $feat_id",1);
        DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $feat_id",1);
    }
        
    COM_errorLog('...success',1);
    return true;
}

//chks for magic_quotes and acts accordingly. use only for gpc otherwise use addslashes
function slashctrl($str){
    if (!get_magic_quotes_gpc()){//right from the manual :P
        $str = addslashes($str);
    }
    return $str;
}

//converts usernames to clickable links leading to user profiles
function prflink($uid,$username){
    global $_CONF, $_TABLES, $DQ_TABLES, $LANG_DQ;

    $retval = '';
    if($uid > '1'){
        $retval = '<a href="' . $_CONF['site_url'];
        $retval .= '/users.php?mode=profile&amp;uid=' . $uid . '">';
        $retval .= $username . '</a>';
    } else {
        $retval = $LANG_DQ['anonymous'];
    }
    return $retval;
}

//converts the names of personalities quoted to clickable google links.
function ggllink($Quoted){
    global $_CONF, $DQ_TABLES, $LANG_DQ;

    //retrieve config setting
    if (!$chkggl = DB_query("SELECT gglink FROM {$DQ_TABLES['dailyquote_settings']}")) {
        $ggl = '1';
    } else {
        list ($ggl) = DB_fetchArray($chkggl);
    }
    //do if based on setting
    if ($ggl == '1'){
        $retval = '';
        if($Quoted != $LANG_DQ['unknown']){
            $gname = eregi_replace(' ','+',trim($Quoted));
            $retval = '<a href="http://www.google.com/search?hl=en&q=';
            $retval .= $gname . '&num=20">' . $Quoted . '</a>';
        } else {
            $retval = $LANG_DQ['unknown'];
        }
    } else {
        $retval = $Quoted;
    }
    return $retval;
}

//converts categories to clickable links leading to the search page
//which will list all quotes in that category
function catlink($catid,$catname){
    global $_CONF, $DQ_TABLES;

    $retval = '';
    $retval = '<a href="' . $_CONF['site_url'];
    $retval .= '/dailyquote/search.php?cat=' . $catid;
    $retval .= '">' . $catname . '</a>';
    return $retval;
}

//retrieve random or cached quote
function get_randomquote(){
    global $_CONF, $_USER, $_TABLES, $PHP_SELF, $LANG_DQ, $DQ_TABLES;

    if (!$cache = DB_query("SELECT cacheupdate, cacheperiod, cacheQID FROM {$DQ_TABLES['dailyquote_settings']}")) {
        COM_errorLog("An error occured while retrieving your quote",1);
        return;
    } else {
        list ($cacheupdate, $cacheperiod, $cacheQID) = DB_fetchArray($cache);
        if (!empty($cacheQID)){//if quote cached get cached quote
            //do expiry check here
            if ((time() - $cacheupdate) >= $cacheperiod){//get new quote if quote expired and update db
                if (!$dbquote = DB_query("SELECT DISTINCT ID, Quotes, Quoted, Title, Source, Sourcedate, Date, q.UID, username FROM {$DQ_TABLES['dailyquote_quotes']} q, {$DQ_TABLES['dailyquote_lookup']} l, {$_TABLES['users']} gl WHERE q.Status='1' AND q.UID=gl.uid AND l.QID=ID AND l.Status='1' ORDER BY rand() LIMIT 1")){
                    COM_errorLog("An error occured while retrieving your quote",1);
                    return;
                } else {
                    list ($qid, $Quotes, $Quoted, $Title, $Source, $Sourcedate, $Date, $uid, $username) = DB_fetchArray($dbquote);
                    $secs = time();
                    if(!DB_query("UPDATE {$DQ_TABLES['dailyquote_settings']} SET cacheupdate='$secs', cacheQID='$qid'")){
                        COM_errorLog("An error occured while updating the cache",1);
                    }
                    //prepare for array same values just inserted to db
                    $cat = DB_query("SELECT c.ID, c.Name FROM {$DQ_TABLES['dailyquote_cat']} c, {$DQ_TABLES['dailyquote_lookup']} l WHERE '$qid'=l.QID AND c.ID=l.CID AND l.Status='1'");
                    $i = 0;
                    $catlist = "";
                    while ($catrow = DB_fetchArray($cat)){
                        if ($i > 0){
                            $catlist .= ", ";
                        }
                        $catlink = catlink($catrow['ID'],$catrow['Name']);
                        $catlist = $catlist . $catlink;
                        $i++;
                    }
                }
            } else {//quote exists in cache not expired, get quote
                if (!$dbquote = DB_query("SELECT Quotes, Quoted, Title, Source, Sourcedate, Date, q.UID, username FROM {$DQ_TABLES['dailyquote_quotes']} q, {$_TABLES['users']} gl WHERE ID='$cacheQID' AND q.UID=gl.uid")){
                    COM_errorLog("An error occured while retrieving your quote",1);
                    return;
                } else {
                    list ($Quotes, $Quoted, $Title, $Source, $Sourcedate, $Date, $uid, $username) = DB_fetchArray($dbquote);
                    $cat = DB_query("SELECT c.ID, c.Name FROM {$DQ_TABLES['dailyquote_cat']} c, {$DQ_TABLES['dailyquote_lookup']} l WHERE '$cacheQID'=l.QID AND c.ID=l.CID AND l.Status='1'");
                    $i = 0;
                    $catlist = "";
                    while ($catrow = DB_fetchArray($cat)){
                        if ($i > 0){
                            $catlist .= ", ";
                        }
                        $catlink = catlink($catrow['ID'],$catrow['Name']);
                        $catlist = $catlist . $catlink;
                        $i++;
                    }
                }
            }
            //add cache to array
            $username = prflink($uid,$username);
            $Quoted = ggllink($Quoted);
            $dqarray = array($Quotes, $Quoted, $Title, $Source, $Sourcedate, $username, $Date, $catlist);
        } else {//if quote not cached retrieve random quote
            if (!$dbquote = DB_query("SELECT DISTINCT ID, Quotes, Quoted, Title, Source, Sourcedate, Date, q.UID, username FROM {$DQ_TABLES['dailyquote_quotes']} q, {$DQ_TABLES['dailyquote_lookup']} l, {$_TABLES['users']} gl WHERE q.Status='1' AND q.UID=gl.uid AND l.QID=ID AND l.Status='1' ORDER BY rand() LIMIT 1")){
                COM_errorLog("An error occured while retrieving your quote",1);
                return;
            } else {
                list ($qid, $Quotes, $Quoted, $Title, $Source, $Sourcedate, $Date, $uid, $username) = DB_fetchArray($dbquote);
                $cat = DB_query("SELECT c.ID, c.Name FROM {$DQ_TABLES['dailyquote_cat']} c, {$DQ_TABLES['dailyquote_lookup']} l WHERE '$qid'=l.QID AND c.ID=l.CID AND l.Status='1'");
                $i = 0;
                $catlist = "";
                while ($catrow = DB_fetchArray($cat)){
                    if ($i > 0){
                        $catlist .= ", ";
                    }
                    $catlink = catlink($catrow['ID'],$catrow['Name']);
                    $catlist = $catlist . $catlink;
                    $i++;
                }
                //add random quote to array
                $username = prflink($uid,$username);
                $Quoted = ggllink($Quoted);
                $dqarray = array($Quotes, $Quoted, $Title, $Source, $Sourcedate, $username, $Date, $catlist);
            }
        }
    }
    return $dqarray;
}

function plugin_centerblock_dailyquote($where=1,$page=1,$topic ='') {
    global $_CONF, $_USER, $_TABLES, $PHP_SELF, $LANG_DQ, $DQ_TABLES;

    $pi_name = 'dailyquote';     // Plugin name
    $img_dir = $_CONF['layout_url'] . "/dailyquote/image_set";
    $retval = '';

    // Retrieve Centerblock Settings
    if(!$query = DB_query("SELECT anonadd, anonview, cntrblkenable, cntrblkhome, cntrblkpos, blk1, blk2, blk3, blk4, blk12 FROM {$DQ_TABLES['dailyquote_settings']}")){
        $anonadd = 0;
        $anonview = 1;
        $cntrblkenable = 0;
        $cntrblkhome = 2;
        $cntrblkpos = 1;
        $blk1 = 0;
        $blk2 = 0;
        $blk3 = 0;
        $blk4 = 1;
        $blk12 = 0;
    } else {
        list($anonadd,$anonview,$cntrblkenable,$cntrblkhome,$cntrblkpos,$blk1,$blk2,$blk3,$blk4,$blk12) = DB_fetchArray($query);
    }

    // Check user has rights to view this cb, if so, do it.
    if ((($anonview == '1') && ($_USER['uid'] < 2)) || ($_USER['uid'] > 1)) {
        // If enabled only for homepage and this is not page 1 or a topic page, then set disable flag
        if ($cntrblkhome == 1 AND ($page > 1 OR $topic != "") ) {
            $cntrblkenable = 0;
        } elseif ($cntrblkhome == 0 and $page > 1 ) {
            $cntrblkpos = 1;      // Top of Page
        }

        // Check if there are no featured articles in this topic and if so then place it at the top of the page
        if ($topic != "") {
            $wheresql = "WHERE tid='$topic' AND featured > 0";
        } else {
            $wheresql = "WHERE featured = 1";
        }
        $query = DB_query("SELECT count(*) as count FROM {$_TABLES['stories']} $wheresql");
        $result = DB_fetchArray($query);
        if ($result['count'] == 0 and $cntrblkpos == 2) {
            $cntrblkpos = 1;
        }

        if ($cntrblkenable AND ($cntrblkpos == $where)) {
            if (DB_getItem($_TABLES['plugins'],'pi_enabled', 'pi_name = "' .$pi_name. '"')) {
                $dqarray = get_randomquote();
                if (is_array($dqarray)){
                    list($Quote, $Quoted, $Tit, $Source, $Sourcedate, $username, $Date, $catlist) = $dqarray;
                    if(!empty($Quote)){
                        $T = new Template($_CONF['path'] . 'plugins/dailyquote/templates');
                        $T->set_file('page', 'centerblock.thtml');
                        $T->set_var('dispquote', $Quote);
                        $T->set_var('dispquoted', $Quoted);
                        if($blk1 == 1){
                            if (!empty($Source)){
                                $dispsource = "&nbsp;--&nbsp;" . $Source;
                                $T->set_var('source', $dispsource);
                            }
                            if (!empty($Sourcedate)){
                                $dispsourcedate = "&nbsp;&nbsp;(" . $Sourcedate . ')';
                                $T->set_var('sourcedate', $dispsourcedate);
                            }
                        }
                        if($blk2 == 1){
                            if ($username != $LANG_DQ['anonymous']){
                                $T->set_var('subm_by', $LANG_DQ['subm_by'] . ':&nbsp;');
                                $T->set_var('dispcontr', $username);
                                $T->set_var('datecontr', '&nbsp;/&nbsp;' . $Date);
                            }
                        }
                        if($blk3 == 1){
                            $T->set_var('cat', '&nbsp;&nbsp;' . $LANG_DQ['cat'] . ':&nbsp;');
                            $T->set_var('dispcat', $catlist);
                        }
                        if($blk12 == 1){
                            $title = '<p style="text-align: left; font-weight: bold; text-decoration: underline;">';
                            $title .= $Tit;
                            $title .= '</p>';
                            $T->set_var('title', $title);
                        }
                        $T->parse('output','page');
                        if($blk4 == 1){
                            if ((($anonadd == '1') && ($_USER['uid'] < 2)) || (($loginadd == '1') && ($_USER['uid'] > 2)) || (SEC_hasRights('dailyquote.add'))) {
                                $link = "&nbsp;&nbsp;--&nbsp;&nbsp;";
                                $link .= "<a href=\"" . $_CONF['site_url'] . "/dailyquote/add.php\">";
                                $link .= $LANG_DQ['addformlink'];
                                $link .= "</a>";
                            }
                        }
                        $retval = COM_startBlock($LANG_DQ['indextitle'] . $link);
                        $retval .= $T->finish($T->get_var('output'));
                        $retval .= COM_endBlock();
                    }
                }
            }
        }
    }
    return $retval;
}

//returns link or text based on curr url
function is_curpage($curpage, $lntxt){
    global $_CONF;
    $thisurl = COM_getCurrentURL();
    $dqpage = 'dailyquote/' . $curpage;
    if ((eregi($dqpage, $thisurl)) && (!eregi('admin', $thisurl))) {
        $href = $lntxt;
    } else {
        $href = '<a href="'.$_CONF['site_url'].'/dailyquote/' . $curpage . '">' . $lntxt . '</a>';
    }
    return $href;
}

//returns blockmenu content for dqblockmenu
function phpblock_dqmenu(){
    global $_TABLES, $_CONF, $_USER, $DQ_TABLES, $LANG_DQ;

    // Retrieve access settings
    $query = DB_query("SELECT anonadd, anonview, loginadd, loginbatch FROM {$DQ_TABLES['dailyquote_settings']}");
    list($anonadd,$anonview,$loginadd,$loginbatch) = DB_fetchArray($query);
    $content = '';

    //link to the dq index page
    $href = is_curpage('index.php',$LANG_DQ['indexlink']);
    $active = DB_query("SELECT * FROM {$DQ_TABLES['dailyquote_lookup']} l, {$DQ_TABLES['dailyquote_quotes']} q WHERE ID=QID AND q.Status='1' AND l.Status='1' GROUP BY QID");
    $numq = DB_numRows($active);
    $content = $href . '&nbsp;(' . $numq . ')<br />';
    //link to the category index
    $active = DB_query("SELECT * FROM {$DQ_TABLES['dailyquote_lookup']} WHERE Status='1' GROUP BY CID");
    $catnum = DB_numRows($active);
    if ($catnum > '1'){
        $href = is_curpage('catindex.php',$LANG_DQ['catindexlink']);
        $content .= $href . '&nbsp;(' . $catnum . ')<br />';
    }
    //link to the search form
    $href = is_curpage('search.php',$LANG_DQ['searchlink']);
    $content .= $href . '<br />';
    //link to the add form
    if ((($anonadd == '1') && ($_USER['uid'] < 2)) || (($loginadd == '1') && ($_USER['uid'] > 2)) || (SEC_hasRights('dailyquote.add'))) {
        $href = is_curpage('add.php',$LANG_DQ['addformlink']);
        $content .= $href . '<br />';
    }
    //link to the batch add form
    if ((SEC_hasRights('dailyquote.add')) || (($loginbatch == '1') && ($_USER['uid'] > 2))){
        $href = is_curpage('add2.php',$LANG_DQ['batchaddlink']);
        $content .= $href . '<br />';
    }
    //link to the moderation page
    if (SEC_hasRights('dailyquote.edit')){
        $modnum = DB_count($DQ_TABLES['dailyquote_quotes'], 'Status', '0');
        if ($modnum > '0'){
            $href = is_curpage('moderate.php',$LANG_DQ['moderationlink']);
            $content .= $href . '&nbsp;(' . $modnum . ')<br />';
        }
    }
    //link to the manage form
    if (SEC_hasRights('dailyquote.edit')){
        $href = is_curpage('manage.php',$LANG_DQ['managelink']);
        $content .= $href . '<br />';
    }
    //link to the category management page
    if (SEC_hasRights('dailyquote.edit')){
        $href = is_curpage('catman.php',$LANG_DQ['catmanlink']);
        $content .= $href . '<br />';
    }
    return $content;
}

//ensures that the dqmenu uses the same left block template files as the rest of the left blocks.
$_BLOCK_TEMPLATE['dqmenu'] = 'blockheader-left.thtml,blockfooter-left.thtml';

//returns the dq menu block and other left blocks when on plugin pages
function dqmenu(){
    $a = array('dqmenu');
    $retval = custom_showBlocks($a);
    $retval .= COM_showBlocks( 'left', $topic );
    return $retval;
}

//displays a row of links
function link_row(){
    global $_TABLES, $_CONF, $_USER, $DQ_TABLES, $LANG_DQ;

    // Retrieve access settings
    $query = DB_query("SELECT anonadd, anonview, loginadd, loginbatch FROM {$DQ_TABLES['dailyquote_settings']}");
    list($anonadd,$anonview,$loginadd,$loginbatch) = DB_fetchArray($query);

    $T = new Template($_CONF['path'] . 'plugins/dailyquote/templates');
    $T->set_file('page', 'linkrow.thtml');

    $index = "&nbsp;&nbsp;<a href=\"" . $_CONF['site_url'] . "/dailyquote/index.php\">";
    //$index .= "<img src=\"" . $_CONF['site_url'] . "/dailyquote/images/index.gif" . "\" alt=\"";
    $index .= '&gt;' . $LANG_DQ['indexlink'];
    //$index .= "\" border=\"0\" />";
    $index .= "</a>&nbsp;&nbsp;";

    //link to the add form
    if (!eregi('add.php', $_SERVER['REQUEST_URI'])) {
        if ((($anonadd == '1') && ($_USER['uid'] < 2)) || (($loginadd == '1') && ($_USER['uid'] > 2)) || (SEC_hasRights('dailyquote.add'))) {
            $link = "&nbsp;&nbsp;<a href=\"" . $_CONF['site_url'] . "/dailyquote/add.php\">";
            //$link .= "<img src=\"" . $_CONF['site_url'] . "/dailyquote/images/add.gif" . "\" alt=\"";
            $link .= '&gt;' . $LANG_DQ['addformlink'];
            //$link .= "\" border=\"0\" />";
            $link .= "</a>&nbsp;&nbsp;";
            $T ->set_var('addformlink', $link);
        }
    } else {
        $T->set_var('indexlink', $index);
    }
    //link to the batch add form
    if (!eregi('add2', $_SERVER['REQUEST_URI'])) {
        if ((SEC_hasRights('dailyquote.add')) || (($loginbatch == '1') && ($_USER['uid'] > 2))){
            $batch = "&nbsp;&nbsp;<a href=\"" . $_CONF['site_url'] . "/dailyquote/add2.php\">";
            //$batch .= "<img src=\"" . $_CONF['site_url'] . "/dailyquote/images/batch.gif" . "\" alt=\"";
            $batch .= '&gt;' . $LANG_DQ['batchaddlink'];
            //$batch .= "\" border=\"0\" />";
            $batch .= "</a>&nbsp;&nbsp;";
            $T ->set_var('batchaddlink', $batch);
        }
    } else {
        $T->set_var('indexlink', $index);
    }
    //link to the manage form
    if (!eregi('manage', $_SERVER['REQUEST_URI'])) {
        if (SEC_hasRights('dailyquote.edit')){
            $manage = "&nbsp;&nbsp;<a href=\"" . $_CONF['site_url'] . "/dailyquote/manage.php\">";
            //$manage .= "<img src=\"" . $_CONF['site_url'] . "/dailyquote/images/manqt.gif" . "\" alt=\"";
            $manage .= '&gt;' . $LANG_DQ['managelink'];
            //$manage .= "\" border=\"0\" />";
            $manage .= "</a>&nbsp;&nbsp;";
            $T ->set_var('managelink', $manage);
        }
    } else {
        $T->set_var('indexlink', $index);
    }
    //link to the moderation page
    if (SEC_hasRights('dailyquote.edit')){
        $modnum = DB_count($DQ_TABLES['dailyquote_quotes'], 'Status', '0');
        if ($modnum > '0'){
            $mod = "&nbsp;&nbsp;<a href=\"" . $_CONF['site_url'] . "/dailyquote/moderate.php\">";
            //$mod .= "<img src=\"" . $_CONF['site_url'] . "/dailyquote/images/mod.gif" . "\" alt=\"";
            $mod .= '&gt;' . $LANG_DQ['moderationlink'];
            //$mod .= "\" border=\"0\" />";
            $mod .= "</a>&nbsp;&nbsp;";
            $T->set_var('moderationlink', $mod);
        }
    }
    //link to the category management page
    if (!eregi('catman', $_SERVER['REQUEST_URI'])){
        if (SEC_hasRights('dailyquote.edit')){
            $catman = "&nbsp;&nbsp;<a href=\"" . $_CONF['site_url'] . "/dailyquote/catman.php\">";
            //$catman .= "<img src=\"" . $_CONF['site_url'] . "/dailyquote/images/mancat.gif" . "\" alt=\"";
            $catman .= '&gt;' . $LANG_DQ['catmanlink'];
            //$catman .= "\" border=\"0\" />";
            $catman .= "</a>&nbsp;&nbsp;";
            $T->set_var('catmanlink', $catman);
        }
    } else {
        $T->set_var('indexlink', $index);
    }
    //link to the search form
    if (!eregi('search', $_SERVER['REQUEST_URI'])) {
        $search = "&nbsp;&nbsp;<a href=\"" . $_CONF['site_url'] . "/dailyquote/search.php\">";
        //$search .= "<img src=\"" . $_CONF['site_url'] . "/dailyquote/images/search.gif" . "\" alt=\"";
        $search .= '&gt;' . $LANG_DQ['searchlink'];
        //$search .= "\" border=\"0\" />";
        $search .= "</a>&nbsp;&nbsp;";
        $T->set_var('searchlink', $search);
    } else {
        $T->set_var('indexlink', $index);
    }
    //link to the catlist page
    if (!eregi('catindex', $_SERVER['REQUEST_URI'])) {
        $catnum = DB_count($DQ_TABLES['dailyquote_cat'], 'Status', '1');
        if ($catnum > '1'){
            $catlst = "&nbsp;&nbsp;<a href=\"" . $_CONF['site_url'] . "/dailyquote/catindex.php\">";
            //$catlst .= "<img src=\"" . $_CONF['site_url'] . "/dailyquote/images/cats.gif" . "\" alt=\"";
            $catlst .= '&gt;' . $LANG_DQ['catindexlink'];
            //$catlst .= "\" border=\"0\" />";
            $catlst .= "</a>&nbsp;&nbsp;";
            $T->set_var('catindexlink', $catlst);
        }
    } else {
        $T->set_var('indexlink', $index);
    }

    $T->parse('output','page');
    $retval = $T->finish($T->get_var('output'));
    return $retval;
}

// function that displays a random quote from your database in a phpblock if you have the dailyquote
// plugin installed.
// easily modified to use without the dailyquote plugin--just point to your own table and fields.
function phpblock_random_quote(){
    global $_TABLES, $_CONF, $_USER, $DQ_TABLES, $LANG_DQ;
    
    // Retrieve access settings
    if(!$query = DB_query("SELECT anonadd, anonview, blk5, blk6, blk7, blk8, blk13 FROM {$DQ_TABLES['dailyquote_settings']}")){
        $anonadd = 0;
        $anonview = 0;
        $blk5 = 0;
        $blk6 = 0;
        $blk7 = 0;
        $blk8 = 0;
        $blk13= 0;
    } else {
        list($anonadd,$anonview,$blk5,$blk6,$blk7,$blk8,$blk13) = DB_fetchArray($query);
    }

    // Check user has rights to view this block, if so, do it.
    if ((($anonview == '1') && ($_USER['uid'] < 2)) || ($_USER['uid'] > 1)) {
        $dqarray = get_randomquote();
        if (is_array($dqarray)){
            list($Quote, $Quoted, $Tit, $Source, $Sourcedate, $username, $Date, $catlist) = $dqarray;
            if(!empty($Quote)){
                $retval = '';
                if($blk13 == 1){
                    $title = '<p style="text-align: left; font-weight: bold; text-decoration: underline;">';
                    $title .= $Tit;
                    $title .= '</p>';
                    $retval = $title;
                }
                $retval .= "<p align=\"left\">\"";
                $retval .= $Quote;
                $retval .= "\"</p>" . LB;
                $retval .= "<p align=\"right\"><em>";
                $retval .= $Quoted;
                if($blk5 == 1){
                    if (!empty($Source)){
                        $retval .= "<br />" . $Source;
                    }
                    if (!empty($Sourcedate)){
                        $retval .= "<br />(" . $Sourcedate . ")";
                    }
                }
                $retval .= "</em></p>" . LB;
                if(($blk6 ==1) || ($blk7 ==1) || ($blk8 == 1)){
                    $retval .= "<p style=\"text-align: right; font-size: 8pt;\">";
                    if(($blk6 == 1) && ($username != $LANG_DQ['anonymous'])){
                        $retval .= $LANG_DQ['subm_by'] . ": " . $username;
                        $retval .= '&nbsp;/&nbsp;' . $Date;
                    }
                    if($blk7 ==1){
                        if($blk6 ==1){
                            $retval .= "<br />";
                        }
                        $retval .= $LANG_DQ['cat'] . ":&nbsp;";
                        $retval .= $catlist;
                    }
                    if($blk8 ==1){
                        if((($anonadd == 1) && ($_USER['uid'] < 2)) || ($_USER['uid'] > 1)){
                            if (($blk6 == 1) || ($blk7 == 1)) {
                                $retval .= '<br />';
                            }
                            $retval .= '<a href="' . $_CONF['site_url'];
                            $retval .= '/dailyquote/add.php">Add Quote</a>';
                        }
                    }
                    $retval .= "</p>" . LB;
                }
            }
        }
    }
    return $retval;
}

//displays a random quote box at the top of the regular listings
function random_quote(){
    global $_CONF, $DQ_TABLES, $LANG_DQ;

    if(!$query = DB_query("SELECT blk9, blk10, blk11, blk14 FROM {$DQ_TABLES['dailyquote_settings']}")){
        $blk9 = 1;
        $blk10 = 0;
        $blk11 = 1;
        $blk14 = 0;
    } else {
        list($blk9,$blk10,$blk11,$blk14) = DB_fetchArray($query);
    }
    $dqarray = get_randomquote();
    if (is_array($dqarray)){
        list($Quote, $Quoted, $Tit, $Source, $Sourcedate, $username, $Date, $catlist) = $dqarray;
        if(!empty($Quote)){
            $T = new Template($_CONF['path'] . 'plugins/dailyquote/templates');
            $T->set_file('page', 'randomquotebox.thtml');
            $T->set_var('site_url', $_CONF['site_url']);
            $T->set_var('randomboxtitle', $LANG_DQ['randomboxtitle']);
            if($blk14 == 1){
                $title = '<p style="text-align: left; font-weight: bold; text-decoration: underline;">';
                $title .= $Tit;
                $title .= '</p>';
                $T->set_var('title', $title);
            }
            $T->set_var('randomquote', $Quote);
            $T->set_var('quoted', $Quoted);
            if($blk == 1){
                if (!empty($Source)){
                    $dispsource = "&nbsp;--&nbsp;" . $Source;
                    $T->set_var('source', $dispsource);
                }
                if (!empty($Sourcedate)){
                    $dispsourcedate = "&nbsp;&nbsp;(" . $Sourcedate . ")";
                    $T->set_var('sourcedate', $dispsourcedate);
                }
            }
            if(($blk10 == 1) && ($username != $LANG_DQ['anonymous'])){
                $T->set_var('subm_by', $LANG_DQ['subm_by'] . ':&nbsp;');
                $T->set_var('dispcontr', $username);
                $T->set_var('dispcontr', $username);
                $T->set_var('datecontr', '&nbsp;/&nbsp;' . $Date);
            }
            if($blk11 == 1){
                $T->set_var('cat', '&nbsp;&nbsp;' . $LANG_DQ['cat'] . ':&nbsp;');
                $T->set_var('dispcat', $catlist);
            }
            $T->parse('output','page');
            $retval = $T->finish($T->get_var('output'));
        }
    }
    return $retval;
}

//displays a row of sort by options for the display page
function sort_by_menu(){
    global $_TABLES, $_CONF, $DQ_TABLES, $LANG_DQ;

    $T = new Template($_CONF['path'] . 'plugins/dailyquote/templates');
    $T ->set_file('page', 'sortnav.thtml');
    $T ->set_var('site_url', $_CONF['site_url']);
    $T ->set_var('sortby', $LANG_DQ['sortby']);
    $T ->set_var('sortopt1', $LANG_DQ['sortopt1']);
    $T ->set_var('sortopt2', $LANG_DQ['sortopt2']);
    $T ->set_var('sortopt3', $LANG_DQ['sortopt3']);
    $T ->set_var('sortopt4', $LANG_DQ['sortopt4']);
    $T ->set_var('sortopt8', $LANG_DQ['sortopt8']);
    $T ->set_var('ascopt1', $LANG_DQ['ascopt1']);
    $T ->set_var('ascopt2', $LANG_DQ['ascopt2']);
    $T ->set_var('submit', $LANG_DQ['sort']);

    $T->parse('output','page');
    $retval = $T->finish($T->get_var('output'));
    return $retval;
}

?>